# BACCO DM POWER SPECTRUM EMULATOR

baccoemu provides predictions for the mass power spectrum in a wide range of
cosmologies, at redshifts 0 to 1.5.

## Installation

Follow detailed instructions at http://bacco.dipc.org/emulator.html#installation

Anyway, a quick installation should boil down to

```bash
pip install . [--user]
```

## Usage

Follow detailed instructions at http://bacco.dipc.org/emulator.html#usage

You can also see an example in this same folder in the file example.py

## Credit our work

You will find the original paper you can cite if you use our emulator at


## License
[MIT](https://choosealicense.com/licenses/mit/)
